@@ -4,18 +4,30 @@ from uuid import uuid4
 from django.conf import settings as djsettings
 from django.contrib.auth import get_user_model
 from django.db.utils import IntegrityError
+from django.http import HttpRequest
 from django.utils import timezone
 from django.utils.crypto import get_random_string
 
 from . import settings
-from .models import MagicLink
+from .models import MagicLink, MagicLinkError
 from .utils import get_client_ip, get_url_path
 
 
-def create_magiclink(email, request, redirect_url=''):
+def create_magiclink(
+    email: str, request: HttpRequest, redirect_url: str = ''
+) -> MagicLink:
     if settings.EMAIL_IGNORE_CASE:
         email = email.lower()
 
+    limit = timezone.now() - timedelta(seconds=settings.LOGIN_REQUEST_TIME_LIMIT)  # NOQA: E501
+    over_limit = MagicLink.objects.filter(email=email, created__gte=limit)
+    if over_limit:
+        raise MagicLinkError('Too many magic login requests')
+
+    if settings.ONE_TOKEN_PER_USER:
+        magic_links = MagicLink.objects.filter(email=email, disabled=False)
+        magic_links.update(disabled=True)
+
     if not redirect_url:
         redirect_url = get_url_path(djsettings.LOGIN_REDIRECT_URL)
 
@@ -31,7 +43,12 @@ def create_magiclink(email, request, redirect_url=''):
     return magic_link
 
 
-def get_or_create_user(email, username='', first_name='', last_name=''):
+def get_or_create_user(
+    email: str,
+    username: str = '',
+    first_name: str = '',
+    last_name: str = ''
+):
     User = get_user_model()
 
     if settings.EMAIL_IGNORE_CASE:
@@ -57,12 +74,13 @@ def get_or_create_user(email, username='', first_name='', last_name=''):
     elif 'username' in user_fields:
         # Set a random username if we need to set a username and
         # EMAIL_AS_USERNAME is False
-        user = None
-        while not user:
+        created = False
+        while not created:
             try:
                 user = User.objects.create(
                     email=email, username=get_random_string(length=10),
                 )
+                created = True
             except IntegrityError:  # pragma: no cover
                 pass
     else:
@@ -73,9 +91,9 @@ def get_or_create_user(email, username='', first_name='', last_name=''):
     if 'last_name' in user_fields and last_name:
         user.last_name = last_name
     if 'full_name' in user_fields:
-        user.full_name = f'{first_name} {last_name}'.strip()
+        user.full_name = f'{first_name} {last_name}'.strip()  # type: ignore
     if 'name' in user_fields:
-        user.name = f'{first_name} {last_name}'.strip()
+        user.name = f'{first_name} {last_name}'.strip()  # type: ignore
     user.save()
 
     return user
